#

##

##

###

###

##

##

###

###

###

###

##

###

###

###

##

    	vegan

    	docker
    		docker network list
    		docker network create --subnet=192.168.0.0/24 container_network
    		docker run --network bios_net --ip 192.168.0.100 -v .:/vegan -v /online/locker/vaccines_vegan_pypi/mints/vegan:/online/locker/vaccines_vegan_pypi/mints/vegan -it jumps:v2.1.0
    		docker exec -it e9fffe5b6f3b bash

    	on
    		1st terminal panel
    			#
    			#	setuptools is necessary for sanic
    			#
    			source /vegan/moves/source_1.sh

    			#
    			#
    			#
    			vegan_1 adventures monetary saves import --name 5.JSON

    		2+ terminal panels
    			source /vegan/moves/source_2.sh

    	garages
    		http://192.168.0.100:8000/docs/swagger#/
    		http://192.168.0.100:7457
    		http://192.168.0.100:39000

    	mongo
    		place
    			/vegan/venues/stages/vegan/adventures/monetary/__monetary_1

    		saves
    			ls /vegan/venues/stages/vegan/adventures/monetary/__saves/exports/ingredients/essential_nutrients/

    		saving
    			vegan_1 adventures monetary saves export --name 5.JSON

    		loading
    			vegan_1 adventures monetary saves import --name 4.JSON

    	publishing
    		linting
    			(cd /vegan/venues/stages/vegan && pycycle --here)

    		status
    			cd /vegan/venues/stages/vegan/__status/main
    			python3 /vegan/venues/stages/vegan/__status/main/status.proc.py
    			python3 /vegan/venues/stages/vegan/__status/API/status.proc.py

    		publish
    			#
    			#	[ ] poetry auth
    			#

    			cd /vegan && rm -rf dist && poetry build --verbose && poetry publish --verbose;

    	important
    		poetry show --tree